@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: id.c,v 1.1 2001/10/29 18:04:20 shuu Exp $
+ *  $Id: id.c,v 1.2 2002/03/04 04:23:54 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -9,7 +9,7 @@
 #include	<stdlib.h>
 
 #include	"murasaki.h"
-#include	"env.h"
+#include	"murasaki_ieee1394.h"
 
 int
 get_id_ieee1394(MU_ieee1394_config_t *config)
