@@ -1,14 +1,14 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: op.c,v 1.1 2001/10/29 18:06:45 shuu Exp $
+ *  $Id: op.c,v 1.4 2003/04/20 21:29:10 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
 #include	<stdlib.h>
 
 #include	"murasaki.h"
-#include	"env.h"
+#include	"murasaki_ieee1394.h"
 
 MU_ieee1394_config_t config;
 
@@ -20,11 +20,17 @@ get_info_ieee1394(void)
 }
 
 struct mu_op mu_op = {
-	command: MU_IEEE1394,
+	device: ieee1394,
+	device_name: MU_ARG_IEEE1394,
+	command: MU_MURASAKI "." MU_ARG_IEEE1394,
 	mappath: MU_CONF_DIR "/" MU_IEEE1394MAP,
 	default_mapname: MU_DEFAULT_IEEE1394MAP,
+	action: ACTION_NONE,
 	config: &config,
 	get_info: get_info_ieee1394,
+	get_list: create_modulelist,
+	match_map: match_config,
 	run: load_module,
-	end: NULL,
+	prepare: exec_script,
+	end: exec_script,
 };
