@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: interface.c,v 3.2 2001/10/29 17:56:05 shuu Exp shuu $
+ *  $Id: interface.c,v 3.3 2002/03/04 05:10:04 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -10,7 +10,7 @@
 #include	<string.h>
 
 #include	"murasaki.h"
-#include	"env.h"
+#include	"murasaki_net.h"
 
 /*
  * format: s
