@@ -1,14 +1,14 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: op.c,v 3.2 2001/10/29 17:47:28 shuu Exp shuu $
+ *  $Id: op.c,v 3.5 2003/04/20 21:41:02 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
 #include	<stdlib.h>
 
 #include	"murasaki.h"
-#include	"env.h"
+#include	"murasaki_usb.h"
 
 MU_usb_config_t config;
 
@@ -22,11 +22,17 @@ get_info_usb(void)
 }
 
 struct mu_op mu_op = {
-	command: MU_USB,
+	device: usb,
+	device_name: MU_ARG_USB,
+	command: MU_MURASAKI "." MU_ARG_USB,
 	mappath: MU_CONF_DIR "/" MU_USBMAP,
 	default_mapname: MU_DEFAULT_USBMAP,
+	action: ACTION_NONE,
 	config: &config,
 	get_info: get_info_usb,
+	get_list: create_modulelist,
+	match_map: match_config,
 	run: load_module,
-	end: NULL,
+	prepare: exec_script,
+	end: exec_script,
 };
